# Generated by roxygen2: do not edit by hand

export(available_indicators)
export(available_resources)
export(calc_biodiversity_intactness_index)
export(calc_biome)
export(calc_burned_area)
export(calc_deforestation_drivers)
export(calc_drought_indicator)
export(calc_ecoregion)
export(calc_elevation)
export(calc_exposed_population_acled)
export(calc_exposed_population_ucdp)
export(calc_fatalities_acled)
export(calc_fatalities_ucdp)
export(calc_gsw_change)
export(calc_gsw_occurrence)
export(calc_gsw_recurrence)
export(calc_gsw_seasonality)
export(calc_gsw_time_series)
export(calc_gsw_transitions)
export(calc_humanfootprint)
export(calc_indicators)
export(calc_ipbes_biomes)
export(calc_irr_carbon)
export(calc_key_biodiversity_area)
export(calc_landcover)
export(calc_man_carbon)
export(calc_mangroves_area)
export(calc_population_count)
export(calc_precipitation_chelsa)
export(calc_precipitation_chirps)
export(calc_precipitation_wc)
export(calc_slope)
export(calc_soilproperties)
export(calc_species_richness)
export(calc_temperature_max_wc)
export(calc_temperature_min_wc)
export(calc_traveltime)
export(calc_traveltime_2000)
export(calc_treecover_area)
export(calc_treecover_area_and_emissions)
export(calc_treecoverloss_emissions)
export(calc_tri)
export(calc_vul_carbon)
export(check_available_years)
export(check_engine)
export(check_namespace)
export(check_stats)
export(get_accessibility_2000)
export(get_acled)
export(get_biodiversity_intactness_index)
export(get_chelsa)
export(get_chirps)
export(get_esalandcover)
export(get_fritz_et_al)
export(get_gfw_emissions)
export(get_gfw_lossyear)
export(get_gfw_treecover)
export(get_global_surface_water_change)
export(get_global_surface_water_occurrence)
export(get_global_surface_water_recurrence)
export(get_global_surface_water_seasonality)
export(get_global_surface_water_transitions)
export(get_gmw)
export(get_gsw_time_series)
export(get_humanfootprint)
export(get_ipbes_biomes)
export(get_irr_carbon)
export(get_iucn)
export(get_key_biodiversity_areas)
export(get_man_carbon)
export(get_mcd64a1)
export(get_nasa_grace)
export(get_nasa_srtm)
export(get_nelson_et_al)
export(get_resources)
export(get_soilgrids)
export(get_teow)
export(get_ucdp_ged)
export(get_vul_carbon)
export(get_worldclim_max_temperature)
export(get_worldclim_min_temperature)
export(get_worldclim_precipitation)
export(get_worldpop)
export(make_footprints)
export(make_global_grid)
export(mapme_options)
export(portfolio_long)
export(portfolio_wide)
export(prep_resources)
export(read_portfolio)
export(register_indicator)
export(register_resource)
export(select_engine)
export(spds_exists)
export(write_portfolio)
import(sf)
import(terra)
importFrom(curl,has_internet)
importFrom(httr2,req_headers)
importFrom(httr2,req_perform)
importFrom(httr2,req_retry)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(httr2,resp_status)
importFrom(magrittr,"%>%")
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(utils,download.file)
importFrom(utils,unzip)
