test_that("get_acled works", {
  expect_error(get_acled(accept_terms = FALSE), "Terms of Use")
  expect_error(expect_message(get_acled(accept_terms = TRUE, email = "")), "email")
  expect_error(expect_message(get_acled(accept_terms = TRUE, email = "mymail")), "password")
  Sys.setenv(ACLED_EMAIL = "my-mail")
  Sys.setenv(ACLED_PASSWORD = "my-key")
  expect_no_error(get_acled(accept_terms = TRUE))
  Sys.setenv(ACLED_EMAIL = "")
  Sys.setenv(ACLED_PASSWORD = "")
})
