% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_worldclim.R
\name{worldclim_max_temperature}
\alias{worldclim_max_temperature}
\alias{get_worldclim_max_temperature}
\title{Downloads WorldClim Maximum Temperature layer}
\source{
\url{https://www.worldclim.org/data/index.html}
}
\usage{
get_worldclim_max_temperature(
  years = 2000:2024,
  resolution = c("2.5m", "5m", "10m")
)
}
\arguments{
\item{years}{A numeric vector indicating for which years to make the
resource available. Defaults to 2000:2024.}

\item{resolution}{A character vector indicating the desired resolution:
"2.5m", "5m", or "10m".}
}
\value{
A function that returns an \code{sf} footprint object.
}
\description{
This resource is published by Fick et al. (2017) "WorldClim 2: new 1-km
spatial resolution climate surfaces for global land areas" and
represents multiple climatic variables from which we will be requiring minimum
temperature, maximum temperature, and mean precipitation layers. The layers are
available to download for the period 1960 - 2024 on monthly basis from WorldClim.
}
\details{
This resource represents the maximum temperature, layers available to
download for the period 1960 - 2024 on monthly basis from WorldClim. Encoded
as (°C), representing the maximum temperature per output grid cell.
}
\keyword{resource}
